==> style-o-matic-1.1.5.tgz: package/es/components/Table/TableCell.js <==
var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import classNames from "classnames";
import { CoreComponent, setCorePropDefaults, setCorePropTypes, getValidProps, ROLE } from "../../lib";
import TableCellWidget from "./TableCellWidget.js";

var TableCell = (_temp = _class = function (_CoreComponent) {
  _inherits(TableCell, _CoreComponent);

  function TableCell() {
    _classCallCheck(this, TableCell);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  TableCell.prototype.render = function render() {
    if (this.props.rowtype && this.props.rowtype === "head") {
      var _props = _objectWithoutProperties(this.props, []);

      return React.createElement(TableCellWidget, this.props);
    }

    var _getValidProps = getValidProps(this.props),
        children = _getValidProps.children,
        props = _getValidProps.props;

    return React.createElement(
      "td",
      props,
      children
    );
  };

  return TableCell;
}(CoreComponent), _class.propTypes = setCorePropTypes({
  columnid: "number",
  rowid: "number",
  rowtype: "string"
}), _class.defaultProps = setCorePropDefaults({
  columnid: 0,
  rowid: 0,
  uirole: ROLE.CELL,
  rowtype: "body"
}), _temp);


export default TableCell;

==> style-o-matic-1.1.37.tgz: package/es/components/Table/TableCell.js <==
var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import classNames from "classnames";
import { CoreComponent, getCorePropDefaults, getCorePropTypes, getValidProps, ROLE } from "../../lib";
import TableCellWidget from "./TableCellWidget.js";

var TableCell = (_temp = _class = function (_CoreComponent) {
  _inherits(TableCell, _CoreComponent);

  function TableCell() {
    _classCallCheck(this, TableCell);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  TableCell.prototype.render = function render() {
    if (this.props.rowtype && this.props.rowtype === "head") {
      var _props = _objectWithoutProperties(this.props, []);

      return React.createElement(TableCellWidget, this.props);
    }

    var _getValidProps = getValidProps(this.props),
        children = _getValidProps.children,
        props = _getValidProps.props;

    return React.createElement(
      "td",
      props,
      children
    );
  };

  return TableCell;
}(CoreComponent), _class.propTypes = getCorePropTypes({
  columnid: "number",
  rowid: "number",
  rowtype: "string"
}), _class.defaultProps = getCorePropDefaults({
  columnid: 0,
  rowid: 0,
  uirole: ROLE.CELL,
  rowtype: "body"
}), _temp);


export default TableCell;
